go_cache

package module
v4.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2025 License: MIT Imports: 6 Imported by: 58

Documentation

Index

Constants

const (
	// GoCacheType represents the storage type as a string value
	GoCacheType = "go-cache"
	// GoCacheTagPattern represents the tag pattern to be used as a key in specified storage
	GoCacheTagPattern = "gocache_tag_%s"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type GoCacheClientInterface

type GoCacheClientInterface interface {
	Get(k string) (any, bool)
	GetWithExpiration(k string) (any, time.Time, bool)
	Set(k string, x any, d time.Duration)
	Delete(k string)
	Flush()
}

GoCacheClientInterface represents a github.com/patrickmn/go-cache client

type GoCacheStore

type GoCacheStore struct {
	// contains filtered or unexported fields
}

GoCacheStore is a store for GoCache (memory) library

func NewGoCache

func NewGoCache(client GoCacheClientInterface, options ...lib_store.Option) *GoCacheStore

NewGoCache creates a new store to GoCache (memory) library instance

func (*GoCacheStore) Clear

func (s *GoCacheStore) Clear(_ context.Context) error

Clear resets all data in the store

func (*GoCacheStore) Delete

func (s *GoCacheStore) Delete(_ context.Context, key any) error

Delete removes data in GoCache memoey cache for given key identifier

func (*GoCacheStore) Get

func (s *GoCacheStore) Get(_ context.Context, key any) (any, error)

Get returns data stored from a given key

func (*GoCacheStore) GetType

func (s *GoCacheStore) GetType() string

GetType returns the store type

func (*GoCacheStore) GetWithTTL

func (s *GoCacheStore) GetWithTTL(_ context.Context, key any) (any, time.Duration, error)

GetWithTTL returns data stored from a given key and its corresponding TTL

func (*GoCacheStore) Invalidate

func (s *GoCacheStore) Invalidate(ctx context.Context, options ...lib_store.InvalidateOption) error

Invalidate invalidates some cache data in GoCache memoey cache for given options

func (*GoCacheStore) Set

func (s *GoCacheStore) Set(ctx context.Context, key any, value any, options ...lib_store.Option) error

Set defines data in GoCache memoey cache for given key identifier

Jump to